@@ -23,12 +23,19 @@ able to execute them without creating the argument dictionary at all.
 
 """
 
-from . import CodeTemplates
 from .ConstantCodes import getConstantAccess
 from .ErrorCodes import getErrorExitCode, getReleaseCode, getReleaseCodes
 from .ExceptionCodes import getExceptionIdentifier
 from .Helpers import generateChildExpressionCode
 from .LineNumberCodes import emitLineNumberUpdateCode
+from .templates.CodeTemplatesCalls import (
+    template_call_function_with_args_decl,
+    template_call_function_with_args_impl
+)
+from .templates.CodeTemplatesModules import (
+    template_header_guard,
+    template_helper_impl_decl
+)
 
 
 def generateCallCode(to_name, expression, emit, context):
@@ -45,33 +52,14 @@ def generateCallCode(to_name, expression, emit, context):
     call_args = expression.getCallArgs()
     call_kw = expression.getCallKw()
 
-    if call_kw.isExpressionConstantRef() and call_kw.getConstant() == {}:
-        if call_args.isExpressionMakeTuple():
-            call_arg_names = []
+    if call_kw is None or \
+       (call_kw.isExpressionConstantRef() and call_kw.getConstant() == {}):
+        if call_args is None or call_args.isExpressionConstantRef():
+            if call_args is not None:
+                call_args_value = call_args.getConstant()
+            else:
+                call_args_value = ()
 
-            for call_arg_element in call_args.getElements():
-                call_arg_name = generateChildExpressionCode(
-                    child_name = call_args.getChildName() + "_element",
-                    expression = call_arg_element,
-                    emit       = emit,
-                    context    = context,
-                )
-
-                call_arg_names.append(call_arg_name)
-
-            context.setCurrentSourceCodeReference(
-                expression.getCompatibleSourceReference()
-            )
-
-            getCallCodePosArgsQuick(
-                to_name     = to_name,
-                called_name = called_name,
-                arg_names   = call_arg_names,
-                emit        = emit,
-                context     = context
-            )
-        elif call_args.isExpressionConstantRef():
-            call_args_value = call_args.getConstant()
             assert type(call_args_value) is tuple
 
             call_arg_names = []
@@ -97,6 +85,7 @@ def generateCallCode(to_name, expression, emit, context):
                     to_name     = to_name,
                     called_name = called_name,
                     arg_names   = call_arg_names,
+                    needs_check = expression.mayRaiseException(BaseException),
                     emit        = emit,
                     context     = context
                 )
@@ -104,9 +93,35 @@ def generateCallCode(to_name, expression, emit, context):
                 getCallCodeNoArgs(
                     to_name     = to_name,
                     called_name = called_name,
+                    needs_check = expression.mayRaiseException(BaseException),
                     emit        = emit,
                     context     = context
                 )
+        elif call_args.isExpressionMakeTuple():
+            call_arg_names = []
+
+            for call_arg_element in call_args.getElements():
+                call_arg_name = generateChildExpressionCode(
+                    child_name = call_args.getChildName() + "_element",
+                    expression = call_arg_element,
+                    emit       = emit,
+                    context    = context,
+                )
+
+                call_arg_names.append(call_arg_name)
+
+            context.setCurrentSourceCodeReference(
+                expression.getCompatibleSourceReference()
+            )
+
+            getCallCodePosArgsQuick(
+                to_name     = to_name,
+                called_name = called_name,
+                arg_names   = call_arg_names,
+                needs_check = expression.mayRaiseException(BaseException),
+                emit        = emit,
+                context     = context
+            )
         else:
             args_name = generateChildExpressionCode(
                 expression = call_args,
@@ -126,8 +141,9 @@ def generateCallCode(to_name, expression, emit, context):
                 context     = context
             )
     else:
-        if call_args.isExpressionConstantRef() and \
-           call_args.getConstant() == ():
+        if call_args is None or \
+           (call_args.isExpressionConstantRef() and \
+            call_args.getConstant() == ()):
             call_kw_name = generateChildExpressionCode(
                 expression = call_kw,
                 emit       = emit,
@@ -172,7 +188,7 @@ def generateCallCode(to_name, expression, emit, context):
             )
 
 
-def getCallCodeNoArgs(to_name, called_name, emit, context):
+def getCallCodeNoArgs(to_name, called_name, needs_check, emit, context):
     emitLineNumberUpdateCode(context, emit)
 
     emit(
@@ -189,9 +205,10 @@ def getCallCodeNoArgs(to_name, called_name, emit, context):
     )
 
     getErrorExitCode(
-        check_name = to_name,
-        emit       = emit,
-        context    = context
+        check_name  = to_name,
+        emit        = emit,
+        needs_check = needs_check,
+        context     = context
     )
 
     context.addCleanupTempName(to_name)
@@ -201,7 +218,8 @@ def getCallCodeNoArgs(to_name, called_name, emit, context):
 # Outside helper code relies on some quick call to be present.
 quick_calls_used = set([1, 2, 3])
 
-def getCallCodePosArgsQuick(to_name, called_name, arg_names, emit, context):
+def getCallCodePosArgsQuick(to_name, called_name, arg_names, needs_check,
+                            emit, context):
 
     arg_size = len(arg_names)
     quick_calls_used.add(arg_size)
@@ -227,9 +245,10 @@ def getCallCodePosArgsQuick(to_name, called_name, arg_names, emit, context):
     )
 
     getErrorExitCode(
-        check_name = to_name,
-        emit       = emit,
-        context    = context
+        check_name  = to_name,
+        needs_check = needs_check,
+        emit        = emit,
+        context     = context
     )
 
     context.addCleanupTempName(to_name)
@@ -325,13 +344,13 @@ def getCallsDecls():
         ]
 
         result.append(
-            CodeTemplates.template_call_function_with_args_decl % {
+            template_call_function_with_args_decl % {
                 "args_decl"  : ", ".join(args_decl),
                 "args_count" : quick_call_used
             }
         )
 
-    return CodeTemplates.template_header_guard % {
+    return template_header_guard % {
         "header_guard_name" : "__NUITKA_CALLS_H__",
         "header_body"       : '\n'.join(result)
     }
@@ -341,7 +360,7 @@ def getCallsCode():
     result = []
 
     result.append(
-        CodeTemplates.template_helper_impl_decl % {}
+        template_helper_impl_decl % {}
     )
 
     for quick_call_used in sorted(quick_calls_used):
@@ -355,7 +374,7 @@ def getCallsCode():
         ]
 
         result.append(
-            CodeTemplates.template_call_function_with_args_impl % {
+            template_call_function_with_args_impl % {
                 "args_decl"  : ", ".join(args_decl),
                 "args_list"  : ", ".join(args_list),
                 "args_count" : quick_call_used
@@ -373,6 +392,7 @@ def getMakeBuiltinExceptionCode(to_name, exception_type, arg_names, emit,
             to_name     = to_name,
             called_name = getExceptionIdentifier(exception_type),
             arg_names   = arg_names,
+            needs_check = False,
             emit        = emit,
             context     = context
         )
@@ -381,6 +401,7 @@ def getMakeBuiltinExceptionCode(to_name, exception_type, arg_names, emit,
         getCallCodeNoArgs(
             to_name     = to_name,
             called_name = getExceptionIdentifier(exception_type),
+            needs_check = False,
             emit        = emit,
             context     = context
         )
