@@ -34,6 +34,10 @@ from nuitka.Constants import (
 from nuitka.Options import isDebug
 
 from .NodeBases import CompileTimeConstantExpressionMixin, NodeBase
+from .NodeMakingHelpers import (
+    makeRaiseExceptionReplacementExpression,
+    wrapExpressionWithSideEffects
+)
 
 
 class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
@@ -74,19 +78,22 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
 
 
     def __repr__(self):
-        return "<Node %s value %s at %s %s>" % (
+        return "<Node %s value %r at %s %s>" % (
             self.kind,
             self.constant,
             self.source_ref.getAsString(),
             self.user_provided
         )
 
-    def makeCloneAt(self, source_ref):
-        return self.__class__(self.constant, source_ref)
-
     def getDetails(self):
         return {
-            "value"         : repr(self.constant),
+            "constant"      : self.constant,
+            "user_provided" : self.user_provided
+        }
+
+    def getDetailsForDisplay(self):
+        return {
+            "constant"      : repr(self.constant),
             "user_provided" : self.user_provided
         }
 
@@ -97,9 +104,11 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
         # Cannot compute any further, this is already the best.
         return self, None, None
 
-    def computeExpressionCall(self, call_node, constraint_collection):
-        from .NodeMakingHelpers import makeRaiseExceptionReplacementExpression, wrapExpressionWithSideEffects
+    def computeExpressionCall(self, call_node, call_args, call_kw,
+                              constraint_collection):
 
+        # The arguments don't matter. All constant values cannot be called, and
+        # we just need to make and error out of that.
         new_node = wrapExpressionWithSideEffects(
             new_node     = makeRaiseExceptionReplacementExpression(
                 expression      = self,
@@ -110,6 +119,8 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
             side_effects = call_node.extractPreCallSideEffects()
         )
 
+        constraint_collection.onExceptionRaiseExit(TypeError)
+
         return new_node, "new_raise", "Predicted call of constant value to exception raise."
 
     def getCompileTimeConstant(self):
@@ -129,9 +140,6 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
     def isIndexConstant(self):
         return isIndexConstant(self.constant)
 
-    def isStringConstant(self):
-        return type(self.constant) is str
-
     def isIndexable(self):
         return self.constant is None or self.isNumberConstant()
 
@@ -235,10 +243,6 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
         # Constants have no side effects
         return ()
 
-    def mayRaiseException(self, exception_type):
-        # Constants won't raise any kind of exception.
-        return False
-
     def getIntegerValue(self):
         if self.isNumberConstant():
             return int(self.constant)
@@ -260,6 +264,12 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
     def isIterableConstant(self):
         return isIterableConstant(self.constant)
 
+    def isUnicodeConstant(self):
+        return type(self.constant) is unicode
+
+    def isStringConstant(self):
+        return type(self.constant) is str
+
     def getStrValue(self):
         if type(self.constant) is str:
             # Nothing to do.
@@ -291,4 +301,8 @@ class ExpressionConstantRef(CompileTimeConstantExpressionMixin, NodeBase):
 Iteration over constant %s changed to tuple.""" % type(self.constant).__name__
             )
 
+        if not isIterableConstant(self.constant):
+            # Any exception may be raised.
+            constraint_collection.onExceptionRaiseExit(TypeError)
+
         return iter_node, None, None
