@@ -25,6 +25,7 @@ from .NodeBases import (
     NodeBase,
     StatementChildrenHavingBase
 )
+from .NodeMakingHelpers import makeStatementOnlyNodesFromExpressions
 
 
 class StatementRaiseException(StatementChildrenHavingBase):
@@ -88,6 +89,9 @@ class StatementRaiseException(StatementChildrenHavingBase):
         )
         exception_type = self.getExceptionType()
 
+        # TODO: Limit by type.
+        constraint_collection.onExceptionRaiseExit(BaseException)
+
         if exception_type is not None and \
            exception_type.willRaiseException(BaseException):
             from .NodeMakingHelpers import makeStatementExpressionOnlyReplacementNode
@@ -107,8 +111,6 @@ Explicit raise already raises implicitly building exception type."""
         exception_value = self.getExceptionValue()
 
         if exception_value is not None and exception_value.willRaiseException(BaseException):
-            from .NodeMakingHelpers import makeStatementOnlyNodesFromExpressions
-
             result = makeStatementOnlyNodesFromExpressions(
                 expressions = (
                     exception_type,
@@ -127,8 +129,6 @@ Explicit raise already raises implicitly building exception value."""
 
         if exception_trace is not None and \
            exception_trace.willRaiseException(BaseException):
-            from .NodeMakingHelpers import makeStatementOnlyNodesFromExpressions
-
             result = makeStatementOnlyNodesFromExpressions(
                 expressions = (
                     exception_type,
@@ -148,8 +148,6 @@ Explicit raise already raises implicitly building exception traceback."""
 
         if exception_cause is not None and \
            exception_cause.willRaiseException(BaseException):
-            from .NodeMakingHelpers import makeStatementOnlyNodesFromExpressions
-
             result = makeStatementOnlyNodesFromExpressions(
                 expressions = (
                     exception_type,
@@ -211,7 +209,6 @@ class ExpressionRaiseException(ExpressionChildrenHavingBase):
         else:
             return False
 
-
     getExceptionType = ExpressionChildrenHavingBase.childGetter(
         "exception_type"
     )
@@ -266,6 +263,13 @@ class ExpressionBuiltinMakeException(ExpressionChildrenHavingBase):
     def computeExpression(self, constraint_collection):
         return self, None, None
 
+    def mayRaiseException(self, exception_type):
+        for arg in self.getArgs():
+            if arg.mayRaiseException(exception_type):
+                return True
+
+        return False
+
 
 class ExpressionCaughtExceptionTypeRef(NodeBase, ExpressionMixin):
     kind = "EXPRESSION_CAUGHT_EXCEPTION_TYPE_REF"
@@ -302,12 +306,6 @@ class ExpressionCaughtExceptionValueRef(NodeBase, ExpressionMixin):
         # Referencing the expression type has no side effect
         return False
 
-    @staticmethod
-    def makeCloneAt(source_ref):
-        return ExpressionCaughtExceptionValueRef(
-            source_ref = source_ref
-        )
-
 
 class ExpressionCaughtExceptionTracebackRef(NodeBase, ExpressionMixin):
     kind = "EXPRESSION_CAUGHT_EXCEPTION_TRACEBACK_REF"
