@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -22,7 +22,7 @@ try:
 except ImportError:
     from builtins import len as _len
 
-def len(x):
+def len(x):  # @ReservedAssignment
     print("Private built-in called with argument", repr(x))
 
     return _len(x)
