@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,7 +15,7 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-from enum import Enum, IntEnum, EnumMeta, unique
+from enum import Enum
 
 print("Enum class with duplicate enumeration values:")
 try:
@@ -34,7 +34,7 @@ def testClassNamespaceOverridesClosure():
         # See #17853.
         x = 42
         class X:
-            locals()["x"] = 43
+            locals()['x'] = 43
             y = x
         print("should be 43:", X.y)
 
