@@ -21,14 +21,14 @@
 module_value1 = 5
 module_value2 = 3
 
-additiv_global = "*" * 1000
+additiv_global = '*' * 1000
 
 def calledRepeatedly():
     # Force frame and eliminate forward propagation (currently).
     module_value1
 
     # Make sure we have a local variable x anyway
-    s = "2"
+    s = '2'
 
     additiv = additiv_global
 
