@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Softwar where
@@ -18,9 +18,10 @@
 #     limitations under the License.
 #
 
-print not bool
-print not {}
-print not 7
-print bool or len
-print False or dict
-print type(Ellipsis)
+print(not bool)
+print(not {})
+print(not 7)
+# TODO: Needs some SSA now.
+# print(bool or len)
+# print(False or dict)
+print(type(Ellipsis))
