@@ -34,31 +34,20 @@ sys.path.insert(
 from test_common import (
     my_print,
     setup,
-    convertUsing2to3,
+    createSearchMode,
     compareWithCPython,
+    withExtendedExtraOptions,
     getTempDir
 )
 
 python_version = setup()
 
-search_mode = len(sys.argv) > 1 and sys.argv[1] == "search"
+search_mode = createSearchMode()
 
-start_at = sys.argv[2] if len(sys.argv) > 2 else None
-
-if start_at:
-    active = False
-else:
-    active = True
-
-for filename in sorted(os.listdir(".")):
+for filename in sorted(os.listdir('.')):
     if not os.path.isdir(filename) or filename.endswith(".build"):
         continue
 
-    path = os.path.relpath(filename)
-
-    if not active and start_at in (filename, path):
-        active = True
-
     extra_flags = [
         "expect_success",
         "remove_output",
@@ -70,14 +59,19 @@ for filename in sorted(os.listdir(".")):
     if filename == "sub_package":
         extra_flags.append("ignore_warnings")
 
+    active = search_mode.consider(
+        dirname  = None,
+        filename = filename
+    )
+
     if active:
-        my_print("Consider output of recursively compiled program:", path)
+        my_print("Consider output of recursively compiled program:", filename)
 
         for filename_main in os.listdir(filename):
             if not os.path.isdir(os.path.join(filename,filename_main)):
                 continue
 
-            if filename_main not in ("..", "."):
+            if filename_main not in ("..", '.'):
                 break
         else:
             sys.exit(
@@ -85,18 +79,22 @@ for filename in sorted(os.listdir(".")):
 Error, no package in dir '%s' found, incomplete test case.""" % filename
             )
 
-        os.environ[ "NUITKA_EXTRA_OPTIONS" ] = \
-          "--recurse-to=%s" % os.path.basename(filename_main)
+        extensions = [
+            "--recurse-to=%s" % os.path.basename(filename_main)
+        ]
 
-        os.environ[ "NUITKA_EXTRA_OPTIONS" ] += \
-          " --output-dir=%s" % getTempDir()
+        if not "--output-dir" in os.environ.get("NUITKA_EXTRA_OPTIONS", ""):
+            extensions.append("--output-dir=%s" % getTempDir())
 
-
-        compareWithCPython(
-            path        = os.path.join(filename, filename_main),
-            extra_flags = extra_flags,
-            search_mode = search_mode,
-            needs_2to3  = False
-        )
+        with withExtendedExtraOptions(*extensions):
+            compareWithCPython(
+                dirname     = filename,
+                filename    = filename_main,
+                extra_flags = extra_flags,
+                search_mode = search_mode,
+                needs_2to3  = False
+            )
     else:
         my_print("Skipping", filename)
+
+search_mode.finish()
