@@ -61,10 +61,19 @@ PACKAGE_LIST = (
     "nuitka/optimizations",
     "nuitka/finalizations",
     "nuitka/plugins",
+    "nuitka/plugins/standard",
+    "nuitka/plugins/user",
     "nuitka/containers",
     "nuitka/utils",
 )
 
+def readSource(filename):
+    if python_version < "3":
+        return open(filename, "rb").read()
+    else:
+        return open(filename, "rb").read().decode("latin1")
+
+
 def diffRecursive(dir1, dir2):
     done = set()
 
@@ -94,8 +103,8 @@ def diffRecursive(dir1, dir2):
             todate = time.ctime(os.stat(path2).st_mtime)
 
             diff = difflib.unified_diff(
-                a            = open(path1, "rb").readlines(),
-                b            = open(path2, "rb").readlines(),
+                a            = readSource(path1).splitlines(),
+                b            = readSource(path2).splitlines(),
                 fromfile     = path1,
                 tofile       = path2,
                 fromfiledate = fromdate,
@@ -163,6 +172,7 @@ def executePASS1():
                     nuitka_main_path,
                     "--module",
                     "--recurse-none",
+                    "--plugin-enable=pylint-warnings",
                     "--output-dir=%s" % target_dir,
                     path
                 ]
@@ -226,7 +236,7 @@ def executePASS1():
     )
 
 
-def compileAndCompareWith( nuitka ):
+def compileAndCompareWith(nuitka):
     base_dir = os.path.join("..", "..")
 
     for package in PACKAGE_LIST:
@@ -257,6 +267,7 @@ def compileAndCompareWith( nuitka ):
                     nuitka,
                     "--module",
                     "--recurse-none",
+                    "--plugin-enable=pylint-warnings",
                     "--output-dir=%s"% tmp_dir,
                     path
                 ]
@@ -360,8 +371,11 @@ def executePASS5():
         os.environ["PYTHON"],
         nuitka_main_path,
         path,
+        "--plugin-enable=pylint-warnings",
         "--output-dir=%s" % tmp_dir,
         "--recurse-all",
+        "--recurse-not-to=PyQt4",
+        "--recurse-not-to=nuitka.build.inline_copy",
         "--recurse-dir=%s" % path,
         "--module",
         path
