@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Softwar where
@@ -17,4 +17,4 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-print('7FF80000000000007FF0000000000000'.decode('hex'))
+print("4B4159".decode("hex"))
